Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Logger ¶
type Logger struct {
application.BaseEmailer
}
Logger is a development emailer that logs emails instead of sending them
type Resend ¶
type Resend struct {
application.BaseEmailer
// contains filtered or unexported fields
}
Resend sends emails via the Resend API
type ResendOption ¶
type ResendOption func(*Resend)
ResendOption configures the Resend emailer.
func WithHTTPClient ¶
func WithHTTPClient(client *http.Client) ResendOption
WithHTTPClient sets a custom HTTP client for the Resend emailer. Useful for testing — inject a client that routes to a test server.
Click to show internal directories.
Click to hide internal directories.